@@ -1,28 +1,11 @@
-from driftpy.types import (
-    PositionDirection,
-    # StateAccount,
-    # MarketsAccount,
-    # Market,
-    # FundingPaymentHistoryAccount,
-    # FundingRateHistoryAccount,
-    # TradeHistoryAccount,
-    # LiquidationHistoryAccount,
-    # DepositHistoryAccount,
-    # ExtendedCurveHistoryAccount,
-    # User,
-    # UserPositions,
-    Market,
-    MarketPosition,
-)
+from driftpy.types import PositionDirection, PerpMarket, PerpPosition, SpotPosition
 
 from driftpy.math.amm import calculate_amm_reserves_after_swap, get_swap_direction
 from driftpy.constants.numeric_constants import (
-    MARK_PRICE_PRECISION,
-    # PEG_PRECISION,
+    PRICE_PRECISION as PRICE_PRECISION,
     AMM_RESERVE_PRECISION,
-    # QUOTE_PRECISION,
-    FUNDING_PRECISION,
-    PRICE_TO_QUOTE_PRECISION,
+    FUNDING_RATE_BUFFER,
+    PRICE_TO_QUOTE_PRECISION_RATIO,
     AMM_TO_QUOTE_PRECISION_RATIO,
     AMM_TIMES_PEG_TO_QUOTE_PRECISION_RATIO,
 )
@@ -30,7 +13,20 @@ from driftpy.constants.numeric_constants import (
 from driftpy.math.amm import AssetType
 
 
-def calculate_base_asset_value(market: Market, user_position: MarketPosition) -> int:
+def is_spot_position_available(position: SpotPosition):
+    return position.scaled_balance == 0 and position.open_orders == 0
+
+
+def is_available(position: PerpPosition):
+    return (
+        position.base_asset_amount == 0
+        and position.quote_asset_amount == 0
+        and position.open_orders == 0
+        and position.lp_shares == 0
+    )
+
+
+def calculate_base_asset_value(market: PerpMarket, user_position: PerpPosition) -> int:
 
     if user_position.base_asset_amount == 0:
         return 0
@@ -68,7 +64,7 @@ def calculate_base_asset_value(market: Market, user_position: MarketPosition) ->
 
 
 def calculate_position_pnl(
-    market: Market, market_position: MarketPosition, with_funding=False
+    market: PerpMarket, market_position: PerpPosition, with_funding=False
 ):
     pnl = 0.0
 
@@ -84,12 +80,12 @@ def calculate_position_pnl(
 
     if with_funding:
         funding_rate_pnl = 0.0
-        pnl += funding_rate_pnl / float(PRICE_TO_QUOTE_PRECISION)
+        pnl += funding_rate_pnl / float(PRICE_TO_QUOTE_PRECISION_RATIO)
 
     return pnl
 
 
-def calculate_position_funding_pnl(market: Market, market_position: MarketPosition):
+def calculate_position_funding_pnl(market: PerpMarket, market_position: PerpPosition):
     funding_pnl = 0.0
 
     if market_position.base_asset_amount == 0:
@@ -105,18 +101,18 @@ def calculate_position_funding_pnl(market: Market, market_position: MarketPositi
         market_position.last_cumulative_funding_rate - amm_cum_funding_rate
     ) * market_position.base_asset_amount
 
-    funding_pnl /= float(AMM_RESERVE_PRECISION * FUNDING_PRECISION)
+    funding_pnl /= float(AMM_RESERVE_PRECISION * FUNDING_RATE_BUFFER)
 
     return funding_pnl
 
 
-def calculate_entry_price(market_position: MarketPosition):
+def calculate_entry_price(market_position: PerpPosition):
     if market_position.base_asset_amount == 0:
         return 0
 
     return abs(
         market_position.quote_asset_amount
-        * MARK_PRICE_PRECISION
+        * PRICE_PRECISION
         * AMM_TO_QUOTE_PRECISION_RATIO
         / market_position.base_asset_amount
     )
